define(
//begin v1.x content
({
	insertImageTitle: "Indsæt billede",
	url: "Billede",
	browse: "Gennemse...",
	text: "Beskrivelse",
	set: "Indsæt",
	invalidMessage: "Ugyldig billedfiltype",
	prePopuTextUrl: "Angiv en billed-URL",
	prePopuTextBrowse: " eller søg efter en lokal fil."
})

//end v1.x content
);
